@@ -7,5 +7,5 @@ from .settings import settings
 def activate(*, basedir):
     metapath = os.path.join(basedir, settings.metadir)
     if metapath not in sys.path:
-        sys.path.insert(0, metapath)
+        sys.path.append(metapath)
         OriginImporter.register()
