@@ -2,6 +2,8 @@ import os
 import jinja2
 from run import Module
 from functools import partial
+from sugarbowl import cachedproperty
+from importlib import import_module
 from run.plugins.io import DialogModule  # @UnresolvedImport
 from run.plugins.render import RenderTask  # @UnresolvedImport
 from .project import Project
@@ -47,14 +49,19 @@ class ProcessModule(Module):
         if context is None:
             context = self.context
         return self.render(
-            string,
-            context=context,
-            target=target,
-            trim_blocks=True,
-            lstrip_blocks=True,
-            loader=jinja2.PrefixLoader({
-                'mario.origin': jinja2.PackageLoader(
-                    'mario.origin', 'templates')}))
+            string, context=context, target=target,
+            loader=self.__loader, trim_blocks=True, lstrip_blocks=True)
 
     context = DialogModule()
     render = RenderTask(meta_hidden=True)
+
+    # Private
+
+    @cachedproperty
+    def __loader(self):
+        try:
+            import_module('mario.origin')
+        except ImportError:
+            return None
+        return jinja2.PrefixLoader({
+            'mario.origin': jinja2.PackageLoader('mario.origin')})
